Documentation
¶
Overview ¶
Package netutil provides shared HTTP/network normalization helpers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NormalizeHost ¶
NormalizeHost lower-cases and strips ports/trailing dots from host values.
func RemoveHopByHopHeaders ¶
RemoveHopByHopHeaders strips hop-by-hop headers that must not be proxied.
func RemoveHopByHopHeadersPreserveUpgrade ¶ added in v0.5.0
RemoveHopByHopHeadersPreserveUpgrade strips hop-by-hop headers while preserving websocket upgrade headers when present.
func ShouldPreserveUpgradeHeaders ¶ added in v0.5.0
ShouldPreserveUpgradeHeaders reports whether the header map indicates an HTTP Upgrade handshake that requires preserving Connection/Upgrade headers.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.